SarPy_Apps
==========
This provides a set of GUI tools based on tkinter for visualizing and interacting 
with SAR imagery and related data.

Origins
-------
This was developed to enable simple prototyping of graphical user interfaces useful 
in conjunction with SarPy project, and was based on and motivated by the set of MATLAB 
tools developed by NGA/NRL referred to as TASER. This effort was developed at the 
National Geospatial-Intelligence Agency (NGA). The software use, modification, and 
distribution rights are stipulated within the MIT license.

Dependencies
------------
The core library functionality depends on the [sarpy](https://github.com/ngageoint/sarpy) 
and [tk_builder](https://github.com/ngageoint/tk_builder) projects. 
